==> koshoten.net-2.2.0.tar.gz: koshoten-net/catalog/includes/modules/kn_shipping/yuupack.php <==
<?php
/*
  $Id: yuupack.php,v 1.4 2006/07/16 05:09:37 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
*/
//
// ⥸塼 ̾͹ʪ(椦ѥå)
// TAMURA Toshihiko (tamura@bitscope.co.jp)
//
// [Ϣե]
// catalog/includes/classes/_yuupack.php
// catalog/includes/languages/japanese/modules/shipping/yuupack.php
// catalog/includes/modules/shipping/yuupack.php
// catalog/images/icons/shipping_yuupack.gif
//
// []
// http://www.post.yusei.go.jp/service/parcel/you_pack/
//
// []
// 2004/09/30 б
//
  class yuupack {
    var $code, $title, $description, $sort_order, $icon, $tax_class, $enabled;
    var $yuupack_countries, $yuupack_countries_nbr;
    var $quote;

// class constructor
    function yuupack() {
      global $order;

      $this->code        = 'yuupack';
      $this->title       = MODULE_SHIPPING_YUUPACK_TEXT_TITLE;
      $this->description = MODULE_SHIPPING_YUUPACK_TEXT_DESCRIPTION;
      $this->sort_order  = MODULE_SHIPPING_YUUPACK_SORT_ORDER;
      $this->icon        = DIR_WS_ICONS . 'shipping_yuupack.gif';
      $this->tax_class   = in_array('MODULE_SHIPPING_YUUPACK_TAX_CLASS',$this->keys())
                           ? MODULE_SHIPPING_YUUPACK_TAX_CLASS : 0;
      $this->enabled = ((MODULE_SHIPPING_YUUPACK_STATUS == 'True') ? true : false);

      // only these three are needed since YuuPack only ships to them
      // convert TEP country id to ISO 3166 id
      $this->yuupack_countries = array(107 => 'JP');
      $this->yuupack_countries_nbr = array(107);

      if ( ($this->enabled == true) && ((int)MODULE_SHIPPING_YUUPACK_ZONE > 0) ) {
        $check_flag = false;
        $check_query = tep_db_query("select zone_id from " . TABLE_ZONES_TO_GEO_ZONES
         . " where geo_zone_id = '" . MODULE_SHIPPING_YUUPACK_ZONE . "' and zone_country_id = '"
         . $order->delivery['country']['id'] . "' order by zone_id");
        while ($check = tep_db_fetch_array($check_query)) {
          if ($check['zone_id'] < 1) {
            $check_flag = true;
            break;
          } elseif ($check['zone_id'] == $order->delivery['zone_id']) {
            $check_flag = true;
            break;
          }
        }

        if ($check_flag == false) {
          $this->enabled = false;
        }
      }
    }

// class methods
    function quote() {
      global $total_weight;
//    global $shipping_weight, $shipping_num_boxes;
      global $order;
      global $a_yuupack_time;
      global $cart;

      $this->quotes = array('id' => $this->code,
                            'module' => $this->title);
      if (tep_not_null($this->icon)) $this->quotes['icon'] = tep_image($this->icon, $this->title);

      $country_id = $order->delivery['country']['id'];
      $zone_id    = $order->delivery['zone_id'];

      if (in_array($country_id, $this->yuupack_countries_nbr)) {
          $zoneinfo = tep_db_query("SELECT zone_code FROM zones WHERE zone_id = '".$zone_id."'");
          $a_zonevalues = tep_db_fetch_array($zoneinfo);
          $s_zone_code = $a_zonevalues['zone_code'];

          if ( (MODULE_SHIPPING_YUUPACK_FREE_SHIPPING != 'True')
               || ((int)$cart->show_total() < (int)MODULE_SHIPPING_YUUPACK_OVER) ) {

              include(DIR_WS_CLASSES . '_yuupack.php');
              $rate = new _YuuPack($this->code, MODULE_SHIPPING_YUUPACK_TEXT_WAY_NORMAL,
                                    STORE_ORIGIN_ZONE, STORE_ORIGIN_COUNTRY);

              // $size_table[] = array( => ,...) 
              $a_table = split("[:,]" , MODULE_SHIPPING_YUUPACK_TABLE);
              $num = count($a_table);
              $size_table = array();
              for ($i = 0; $i + 1 < $num; $i += 2) {
                $size_table[(int)$a_table[$i + 1]] = $a_table[$i];
              }

              $rate->SetDest($s_zone_code, $this->yuupack_countries[$country_id]);
              $rate->SetWeight($total_weight);   // ̤ޤѤι
              $rate->SetMaxWeight((MODULE_SHIPPING_YUUPACK_MODE == 'weight')
                ? (30 - SHIPPING_BOX_WEIGHT) : 0);// 
              $rate->SetSizeTable($size_table);  // Ȥν/Ѥ
              $rate->SetItems($cart->count_contents()); // 

              $tmpQuote = $rate->GetQuote(); // id, title, cost | error

              if (isset($tmpQuote['error'])) {
                  $this->quotes['error'] = $tmpQuote['error'];
              } else {
                // ̤ΤȤϡ̤
                if (!$shipping_weight) {
                  $this->quotes['module'] = $this->title . MODULE_SHIPPING_YUUPACK_TEXT_GET_QUOTE_LATER;
                  $tmpQuote['cost'] = 0;
                } else {
                  $boxes = max($tmpQuote['boxes'], 1); // Ŀ(Ŀ׻ǹԤʤ)
                  $unit = (MODULE_SHIPPING_YUUPACK_MODE == 'weight') ? ' kg' : ' L';

                  $this->quotes['module'] = $this->title
                      . ' (' . $boxes . ' x ' . $tmpQuote['wv'] . $unit . ')';

                  // ǥ
                  if (defined('MODULE_SHIPPING_YUUPACK_DISCOUNT') && 0 < (int)MODULE_SHIPPING_YUUPACK_DISCOUNT) {
                      $tmpQuote['cost'] -= (int)($tmpQuote['cost'] * MODULE_SHIPPING_YUUPACK_DISCOUNT / 100);
                  }
                  // 
                  $tmpQuote['cost'] += MODULE_SHIPPING_YUUPACK_HANDLING;
                }
              }
          } else {
              $tmpQuote = array('id' => $this->code, 'title' => MODULE_SHIPPING_YUUPACK_TEXT_WAY_NORMAL, 'cost' => 0);
          }

          if (!isset($tmpQuote['error'])) {
              // 
              $timespec = $this->get_timespec();
              $tmpQuote['option'] = TEXT_TIME_SPECIFY
                  . tep_draw_pull_down_menu('yuupack_timespec', $a_yuupack_time, $timespec);
              $tmpQuote['timespec'] = $timespec;
          }

          $this->quotes['methods'][] = $tmpQuote;

          if ($this->tax_class > 0) {
              $this->quotes['tax'] = tep_get_tax_rate($this->tax_class, $country_id, $zone_id);
          }
        } else {
            $this->quotes['error'] = MODULE_SHIPPING_YUUPACK_TEXT_NOTAVAILABLE;
        }

        return $this->quotes;
    }

    // ꤹץ˥塼'value'֤
    function get_timespec() {
        global $a_yuupack_time;
        global $shipping;
        global $HTTP_POST_VARS;

        $selected = $a_yuupack_time[0]['id'];
        if ( isset($HTTP_POST_VARS['yuupack_timespec']) ) {
            $selected = $HTTP_POST_VARS['yuupack_timespec'];
        } elseif ( is_array($shipping) ) { // see checkout_shipping.php
            list($module, $method) = explode('_', $shipping['id']);
            if ($module == $this->code) {
                $selected = $shipping['timespec'];
            }
        }
        return $selected;
    }

    function check() {
      if (!isset($this->_check)) {
        $check_query = tep_db_query("select configuration_value from "
          . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_SHIPPING_YUUPACK_STATUS'");
        $this->_check = tep_db_num_rows($check_query);
      }
      return $this->_check;
    }

    function install() {
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ˡ', 'MODULE_SHIPPING_YUUPACK_TEXT_TITLE', '̾͹ʪ', 'ˡ̾.', '6', '11', now())");
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ӥ', 'MODULE_SHIPPING_YUUPACK_TEXT_WAY_NORMAL', '椦ѥå', 'ӥ̾.', '6', '12', now())");
      tep_db_query("insert into " . TABLE_CONFIGURATION .
      " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('椦ѥåͭˤ', 'MODULE_SHIPPING_YUUPACK_STATUS', 'True', '̾͹ʪ(椦ѥå)󶡤ޤ?', '6', '0', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('η׻ɽ', 'MODULE_SHIPPING_YUUPACK_TABLE', '3:60,7:80,10:100,15:120,18:140,22:160,30:170', '̤ޤѤ˴Ť.<br />(:): 3:60,7:80,10:100,15:120,18:140,22:160,30:170<br />(:): 7:60,18:80,30:100,60:120,90:140,140:160,160:170', '6', '1', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('׻ɽδ', 'MODULE_SHIPPING_YUUPACK_MODE', 'weight', '(weight)ޤ(volume)Τɤ׻ɽδȤ뤫Ǥ. weight(kg)volume(åȥ)ʤνϤƤ.', '6', '2', 'tep_cfg_select_option(array(\'weight\', \'volume\'), ', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ѥå󥰤;͵Ψ', 'MODULE_SHIPPING_YUUPACK_ROOM', '1.1', '(volume)ˤ׻ǣİʾξʤ򣱥ѥå˵ͤ碌;͵Ψ(1.0ʾ)ꤷޤ.', '6', '3', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('谷', 'MODULE_SHIPPING_YUUPACK_HANDLING', '0', 'ŬѤ谷Ǥޤ.', '6', '4', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('̵', 'MODULE_SHIPPING_YUUPACK_FREE_SHIPPING', 'False', '̵ͭˤޤ? [ץ⥸塼]-[]-[̵]ͥ褹 False Ǥ.', '6', '5', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");

      tep_db_query("INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('̵ˤ', 'MODULE_SHIPPING_YUUPACK_OVER', '5000', '۰ʾ򤴹ξ̵ˤޤ.', '6', '6', now())");

      tep_db_query("INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('ͰΨ', 'MODULE_SHIPPING_YUUPACK_DISCOUNT', '0', 'ͰΨꤷޤ.()', '6', '7', now())");

//    tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('Ǽ', 'MODULE_SHIPPING_YUUPACK_TAX_CLASS', '0', 'ŬѤǼ̤Ǥ.', '6', '8', 'tep_get_tax_class_title', 'tep_cfg_pull_down_tax_classes(', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('ϰ', 'MODULE_SHIPPING_YUUPACK_ZONE', '0', 'ϰ򤹤򤵤줿ϰΤߤѲǽȤʤޤ.', '6', '9', 'tep_get_zone_class_title', 'tep_cfg_pull_down_zone_classes(', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ɽ', 'MODULE_SHIPPING_YUUPACK_SORT_ORDER', '0', 'ɽǤޤ. ۤɾ̤ɽޤ.', '6', '10', now())");
    }

    function remove() {
      tep_db_query("delete from " . TABLE_CONFIGURATION . " where configuration_key in ('" . implode("', '", $this->keys()) . "')");
    }

    function keys() {
      return array(
        'MODULE_SHIPPING_YUUPACK_TEXT_TITLE',
        'MODULE_SHIPPING_YUUPACK_TEXT_WAY_NORMAL',
        'MODULE_SHIPPING_YUUPACK_STATUS',

        'MODULE_SHIPPING_YUUPACK_TABLE',
        'MODULE_SHIPPING_YUUPACK_MODE',
        'MODULE_SHIPPING_YUUPACK_ROOM',

        'MODULE_SHIPPING_YUUPACK_HANDLING',
        'MODULE_SHIPPING_YUUPACK_FREE_SHIPPING',
        'MODULE_SHIPPING_YUUPACK_OVER',
        'MODULE_SHIPPING_YUUPACK_DISCOUNT',
//      'MODULE_SHIPPING_YUUPACK_TAX_CLASS',
        'MODULE_SHIPPING_YUUPACK_ZONE',
        'MODULE_SHIPPING_YUUPACK_SORT_ORDER',
      );
    }
  }
?>

==> koshoten.net-2.2.2.tar.gz: koshoten-net/catalog/includes/modules/kn_shipping/yuupack.php <==
<?php
/*
  $Id: yuupack.php,v 1.5 2007/04/16 05:40:59 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
*/
//
// ⥸塼 ̾͹ʪ(椦ѥå)
// TAMURA Toshihiko (tamura@bitscope.co.jp)
//
// [Ϣե]
// catalog/includes/classes/_yuupack.php
// catalog/includes/languages/japanese/modules/shipping/yuupack.php
// catalog/includes/modules/shipping/yuupack.php
// catalog/images/icons/shipping_yuupack.gif
//
// []
// http://www.post.yusei.go.jp/service/parcel/you_pack/
//
// []
// 2004/09/30 б
//
  class yuupack {
    var $code, $title, $description, $sort_order, $icon, $tax_class, $enabled;
    var $yuupack_countries, $yuupack_countries_nbr;
    var $quote;

// class constructor
    function yuupack() {
      global $order;

      $this->code        = 'yuupack';
      $this->title       = MODULE_SHIPPING_YUUPACK_TEXT_TITLE;
      $this->description = MODULE_SHIPPING_YUUPACK_TEXT_DESCRIPTION;
      $this->sort_order  = MODULE_SHIPPING_YUUPACK_SORT_ORDER;
      $this->icon        = DIR_WS_ICONS . 'shipping_yuupack.gif';
      $this->tax_class   = in_array('MODULE_SHIPPING_YUUPACK_TAX_CLASS',$this->keys())
                           ? MODULE_SHIPPING_YUUPACK_TAX_CLASS : 0;
      $this->enabled = ((MODULE_SHIPPING_YUUPACK_STATUS == 'True') ? true : false);

      // only these three are needed since YuuPack only ships to them
      // convert TEP country id to ISO 3166 id
      $this->yuupack_countries = array(107 => 'JP');
      $this->yuupack_countries_nbr = array(107);

      if ( ($this->enabled == true) && ((int)MODULE_SHIPPING_YUUPACK_ZONE > 0) ) {
        $check_flag = false;
        $check_query = tep_db_query("select zone_id from " . TABLE_ZONES_TO_GEO_ZONES
         . " where geo_zone_id = '" . MODULE_SHIPPING_YUUPACK_ZONE . "' and zone_country_id = '"
         . (int)$order->delivery['country']['id'] . "' order by zone_id");
        while ($check = tep_db_fetch_array($check_query)) {
          if ($check['zone_id'] < 1) {
            $check_flag = true;
            break;
          } elseif ($check['zone_id'] == $order->delivery['zone_id']) {
            $check_flag = true;
            break;
          }
        }

        if ($check_flag == false) {
          $this->enabled = false;
        }
      }
    }

// class methods
    function quote() {
      global $total_weight;
//    global $shipping_weight, $shipping_num_boxes;
      global $order;
      global $a_yuupack_time;
      global $cart;

      $this->quotes = array('id' => $this->code,
                            'module' => $this->title);
      if (tep_not_null($this->icon)) $this->quotes['icon'] = tep_image($this->icon, $this->title);

      $country_id = $order->delivery['country']['id'];
      $zone_id    = $order->delivery['zone_id'];

      if (in_array($country_id, $this->yuupack_countries_nbr)) {
          $zoneinfo = tep_db_query("SELECT zone_code FROM zones WHERE zone_id = '". (int)$zone_id ."'");
          $a_zonevalues = tep_db_fetch_array($zoneinfo);
          $s_zone_code = $a_zonevalues['zone_code'];

          if ( (MODULE_SHIPPING_YUUPACK_FREE_SHIPPING != 'True')
               || ((int)$cart->show_total() < (int)MODULE_SHIPPING_YUUPACK_OVER) ) {

              include(DIR_WS_CLASSES . '_yuupack.php');
              $rate = new _YuuPack($this->code, MODULE_SHIPPING_YUUPACK_TEXT_WAY_NORMAL,
                                    STORE_ORIGIN_ZONE, STORE_ORIGIN_COUNTRY);

              // $size_table[] = array( => ,...) 
              $a_table = split("[:,]" , MODULE_SHIPPING_YUUPACK_TABLE);
              $num = count($a_table);
              $size_table = array();
              for ($i = 0; $i + 1 < $num; $i += 2) {
                $size_table[(int)$a_table[$i + 1]] = $a_table[$i];
              }

              $rate->SetDest($s_zone_code, $this->yuupack_countries[$country_id]);
              $rate->SetWeight($total_weight);   // ̤ޤѤι
              $rate->SetMaxWeight((MODULE_SHIPPING_YUUPACK_MODE == 'weight')
                ? (30 - SHIPPING_BOX_WEIGHT) : 0);// 
              $rate->SetSizeTable($size_table);  // Ȥν/Ѥ
              $rate->SetItems($cart->count_contents()); // 

              $tmpQuote = $rate->GetQuote(); // id, title, cost | error

              if (isset($tmpQuote['error'])) {
                  $this->quotes['error'] = $tmpQuote['error'];
              } else {
                // ̤ΤȤϡ̤
                if (!$shipping_weight) {
                  $this->quotes['module'] = $this->title . MODULE_SHIPPING_YUUPACK_TEXT_GET_QUOTE_LATER;
                  $tmpQuote['cost'] = 0;
                } else {
                  $boxes = max($tmpQuote['boxes'], 1); // Ŀ(Ŀ׻ǹԤʤ)
                  $unit = (MODULE_SHIPPING_YUUPACK_MODE == 'weight') ? ' kg' : ' L';

                  $this->quotes['module'] = $this->title
                      . ' (' . $boxes . ' x ' . $tmpQuote['wv'] . $unit . ')';

                  // ǥ
                  if (defined('MODULE_SHIPPING_YUUPACK_DISCOUNT') && 0 < (int)MODULE_SHIPPING_YUUPACK_DISCOUNT) {
                      $tmpQuote['cost'] -= (int)($tmpQuote['cost'] * MODULE_SHIPPING_YUUPACK_DISCOUNT / 100);
                  }
                  // 
                  $tmpQuote['cost'] += MODULE_SHIPPING_YUUPACK_HANDLING;
                }
              }
          } else {
              $tmpQuote = array('id' => $this->code, 'title' => MODULE_SHIPPING_YUUPACK_TEXT_WAY_NORMAL, 'cost' => 0);
          }

          if (!isset($tmpQuote['error'])) {
              // 
              $timespec = $this->get_timespec();
              $tmpQuote['option'] = TEXT_TIME_SPECIFY
                  . tep_draw_pull_down_menu('yuupack_timespec', $a_yuupack_time, $timespec);
              $tmpQuote['timespec'] = $timespec;
          }

          $this->quotes['methods'][] = $tmpQuote;

          if ($this->tax_class > 0) {
              $this->quotes['tax'] = tep_get_tax_rate($this->tax_class, $country_id, $zone_id);
          }
        } else {
            $this->quotes['error'] = MODULE_SHIPPING_YUUPACK_TEXT_NOTAVAILABLE;
        }

        return $this->quotes;
    }

    // ꤹץ˥塼'value'֤
    function get_timespec() {
        global $a_yuupack_time;
        global $shipping;
        global $HTTP_POST_VARS;

        $selected = $a_yuupack_time[0]['id'];
        if ( isset($HTTP_POST_VARS['yuupack_timespec']) ) {
            $selected = $HTTP_POST_VARS['yuupack_timespec'];
        } elseif ( is_array($shipping) ) { // see checkout_shipping.php
            list($module, $method) = explode('_', $shipping['id']);
            if ($module == $this->code) {
                $selected = $shipping['timespec'];
            }
        }
        return $selected;
    }

    function check() {
      if (!isset($this->_check)) {
        $check_query = tep_db_query("select configuration_value from "
          . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_SHIPPING_YUUPACK_STATUS'");
        $this->_check = tep_db_num_rows($check_query);
      }
      return $this->_check;
    }

    function install() {
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ˡ', 'MODULE_SHIPPING_YUUPACK_TEXT_TITLE', '̾͹ʪ', 'ˡ̾.', '6', '11', now())");
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ӥ', 'MODULE_SHIPPING_YUUPACK_TEXT_WAY_NORMAL', '椦ѥå', 'ӥ̾.', '6', '12', now())");
      tep_db_query("insert into " . TABLE_CONFIGURATION .
      " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('椦ѥåͭˤ', 'MODULE_SHIPPING_YUUPACK_STATUS', 'True', '̾͹ʪ(椦ѥå)󶡤ޤ?', '6', '0', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('η׻ɽ', 'MODULE_SHIPPING_YUUPACK_TABLE', '3:60,7:80,10:100,15:120,18:140,22:160,30:170', '̤ޤѤ˴Ť.<br />(:): 3:60,7:80,10:100,15:120,18:140,22:160,30:170<br />(:): 7:60,18:80,30:100,60:120,90:140,140:160,160:170', '6', '1', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('׻ɽδ', 'MODULE_SHIPPING_YUUPACK_MODE', 'weight', '(weight)ޤ(volume)Τɤ׻ɽδȤ뤫Ǥ. weight(kg)volume(åȥ)ʤνϤƤ.', '6', '2', 'tep_cfg_select_option(array(\'weight\', \'volume\'), ', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ѥå󥰤;͵Ψ', 'MODULE_SHIPPING_YUUPACK_ROOM', '1.1', '(volume)ˤ׻ǣİʾξʤ򣱥ѥå˵ͤ碌;͵Ψ(1.0ʾ)ꤷޤ.', '6', '3', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('谷', 'MODULE_SHIPPING_YUUPACK_HANDLING', '0', 'ŬѤ谷Ǥޤ.', '6', '4', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('̵', 'MODULE_SHIPPING_YUUPACK_FREE_SHIPPING', 'False', '̵ͭˤޤ? [ץ⥸塼]-[]-[̵]ͥ褹 False Ǥ.', '6', '5', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");

      tep_db_query("INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('̵ˤ', 'MODULE_SHIPPING_YUUPACK_OVER', '5000', '۰ʾ򤴹ξ̵ˤޤ.', '6', '6', now())");

      tep_db_query("INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('ͰΨ', 'MODULE_SHIPPING_YUUPACK_DISCOUNT', '0', 'ͰΨꤷޤ.()', '6', '7', now())");

//    tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('Ǽ', 'MODULE_SHIPPING_YUUPACK_TAX_CLASS', '0', 'ŬѤǼ̤Ǥ.', '6', '8', 'tep_get_tax_class_title', 'tep_cfg_pull_down_tax_classes(', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('ϰ', 'MODULE_SHIPPING_YUUPACK_ZONE', '0', 'ϰ򤹤򤵤줿ϰΤߤѲǽȤʤޤ.', '6', '9', 'tep_get_zone_class_title', 'tep_cfg_pull_down_zone_classes(', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ɽ', 'MODULE_SHIPPING_YUUPACK_SORT_ORDER', '0', 'ɽǤޤ. ۤɾ̤ɽޤ.', '6', '10', now())");
    }

    function remove() {
      tep_db_query("delete from " . TABLE_CONFIGURATION . " where configuration_key in ('" . implode("', '", $this->keys()) . "')");
    }

    function keys() {
      return array(
        'MODULE_SHIPPING_YUUPACK_TEXT_TITLE',
        'MODULE_SHIPPING_YUUPACK_TEXT_WAY_NORMAL',
        'MODULE_SHIPPING_YUUPACK_STATUS',

        'MODULE_SHIPPING_YUUPACK_TABLE',
        'MODULE_SHIPPING_YUUPACK_MODE',
        'MODULE_SHIPPING_YUUPACK_ROOM',

        'MODULE_SHIPPING_YUUPACK_HANDLING',
        'MODULE_SHIPPING_YUUPACK_FREE_SHIPPING',
        'MODULE_SHIPPING_YUUPACK_OVER',
        'MODULE_SHIPPING_YUUPACK_DISCOUNT',
//      'MODULE_SHIPPING_YUUPACK_TAX_CLASS',
        'MODULE_SHIPPING_YUUPACK_ZONE',
        'MODULE_SHIPPING_YUUPACK_SORT_ORDER',
      );
    }
  }
?>
